@@ -1,6 +1,8 @@
+use crate::model::{Range, Start};
+use chrono::Duration;
 use clap::{ArgEnum, Parser};
-
-use crate::model::{Printer, Range, Start};
+use jackdauer::duration;
+use serde::Serialize;
 
 pub const APP_NAME: &str = "fbtoggl";
 
@@ -18,6 +20,7 @@ pub struct Options {
 pub enum Format {
   Json,
   Raw,
+  Table,
 }
 
 #[derive(Parser)]
@@ -40,11 +43,13 @@ pub enum SubCommand {
 
 #[derive(Parser, Debug)]
 pub enum Workspaces {
+  #[clap(about = "List all workspaces")]
   List,
 }
 
 #[derive(Parser, Debug)]
 pub enum Projects {
+  #[clap(about = "List all projects (default workspace)")]
   List,
 }
 
@@ -55,9 +60,6 @@ pub enum TimeEntries {
 
   #[clap(about = "Create time entry")]
   Create(CreateTimeEntry),
-
-  #[clap(about = "Create workday with pause")]
-  CreateWorkdayWithPause(CreateWorkdayWithPause),
 }
 
 #[derive(Parser, Debug)]
@@ -76,6 +78,11 @@ pub struct CreateClient {
   pub name: String,
 }
 
+fn parse_duration(duration_to_parse: &str) -> anyhow::Result<Duration> {
+  let bla = duration(duration_to_parse)?;
+  Ok(Duration::from_std(bla)?)
+}
+
 #[derive(Parser, Debug)]
 pub struct CreateTimeEntry {
   #[clap(long, about = "Name of the project")]
@@ -87,27 +94,11 @@ pub struct CreateTimeEntry {
   #[clap(long, about = "Tags")]
   pub tags: Option<Vec<String>>,
 
-  #[clap(long, about = "Duration (in minutes)")]
-  pub duration: u64,
+  #[clap(long, about = "Duration ('1 hour', '10 minutes', '1 hour 12 minutes')", parse(try_from_str = parse_duration))]
+  pub duration: Duration,
 
-  #[clap(
-    long,
-    about = "Start ('now', ISO 8601 date time '2021-11-01T00:00:00+01:00')",
-    default_value = "now"
-  )]
-  pub start: Start,
-}
-
-#[derive(Parser, Debug)]
-pub struct CreateWorkdayWithPause {
-  #[clap(long, about = "Name of the project")]
-  pub project: String,
-
-  #[clap(long, about = "Description of the timer")]
-  pub description: String,
-
-  #[clap(long, about = "Duration (in hours)")]
-  pub hours: f64,
+  #[clap(long, about = "Lunch break (if set, adds a lunch break of 1 hour)")]
+  pub lunch_break: bool,
 
   #[clap(
     long,
@@ -119,30 +110,17 @@ pub struct CreateWorkdayWithPause {
 
 #[derive(Parser, Debug)]
 pub enum Clients {
-  #[clap(about = "List all clients")]
+  #[clap(about = "List all clients (default workspace)")]
   List,
 
   #[clap(about = "Create client (in default workspace)")]
   Create(CreateClient),
 }
 
-pub fn output_values<T: Printer>(format: &Format, values: Vec<T>) {
+pub(crate) fn output_values_json<T: Serialize>(values: &[T]) {
   for value in values {
-    output_value(format, value)
+    if let Ok(output) = serde_json::to_string_pretty(&value) {
+      println!("{}", output);
+    }
   }
 }
-
-pub fn output_value<T: Printer>(format: &Format, value: T) {
-  match format {
-    Format::Json => {
-      if let Ok(output) = value.to_json() {
-        println!("{}", output);
-      }
-    }
-    Format::Raw => {
-      if let Ok(output) = value.to_raw() {
-        println!("\"{}\"", output);
-      }
-    }
-  };
-}
